--- openflow-2014-01-03.h	2015-07-23 09:54:17.640479382 -0700
+++ openflow-2014-01-03-2.h	2015-07-23 09:54:17.648479382 -0700
@@ -1986,7 +1986,7 @@
     OFPMP_TABLE = 3,
 
     /* Port statistics.
      * The request body is struct ofp_port_stats_request.
      * The reply body is an array of struct ofp_port_stats. */
     OFPMP_PORT_STATS = 4,
 
@@ -2034,7 +2034,7 @@
     OFPMP_TABLE_FEATURES = 12,
 
     /* Port description.
-     * The request body is empty.
+     * The request body is struct ofp_port_multipart_request.
      * The reply body is an array of struct ofp_port. */
     OFPMP_PORT_DESC = 13,
 
@@ -2341,15 +2341,16 @@
 };
 OFP_ASSERT(sizeof(struct ofp_table_desc) == 8);
 
-/* Body for ofp_multipart_request of type OFPMP_PORT_STATS. */
-struct ofp_port_stats_request {
+/* Body for ofp_multipart_request of types OFPMP_PORT_STATS and
+ * OFPMP_PORT_DESC. */
+struct ofp_port_multipart_request {
     uint32_t port_no;        /* OFPMP_PORT message must request statistics
                               * either for a single port (specified in
                               * port_no) or for all ports (if port_no ==
                               * OFPP_ANY). */
     uint8_t pad[4];
 };
-OFP_ASSERT(sizeof(struct ofp_port_stats_request) == 8);
+OFP_ASSERT(sizeof(struct ofp_port_multipart_request) == 8);
 
 /* Port stats property types.
  */
@@ -2451,7 +2452,7 @@
                                 tx_*_err values (none currently defined.) */
 
     /* Port description property list - 0 or more properties */
-    struct ofp_port_desc_prop_header properties[0];
+    struct ofp_port_stats_prop_header properties[0];
 };
 OFP_ASSERT(sizeof(struct ofp_port_stats) == 80);
 
@@ -1986,7 +1986,7 @@
 
     /* Port statistics.
-     * The request body is struct ofp_port_stats_request.
+     * The request body is struct ofp_port_multipart_request.
      * The reply body is an array of struct ofp_port_stats. */
     OFPMP_PORT_STATS = 4,
